@@ -236,6 +236,8 @@ about_cb (GSimpleAction *action,
                 "Ross Burton <ross@burtonini.com>",
                 "Aleksander Morgado <aleksander@lanedo.com>",
                 "Thomas Bechtold <toabctl@gnome.org>",
+                "Frédéric Péters <fpeters@0d.be>",
+                "Sébastien Wilmet <swilmet@gnome.org>",
                 NULL
         };
 
@@ -253,7 +255,7 @@ about_cb (GSimpleAction *action,
                                "website-label", _("Devhelp Website"),
                                "logo-icon-name", PACKAGE_TARNAME,
                                "license-type", GTK_LICENSE_GPL_2_0,
-                               "copyright", "Copyright 2001-2015 – the Devhelp team",
+                               "copyright", "Copyright 2001-2016 – the Devhelp team",
                                NULL);
 }
 
